#!/usr/bin/env bash
set -x

CURDIR=${PWD}
KEYDIR=${CURDIR}/etc/banyan-ca
DKEYDIR=/etc/banyan-ca
BANYAN_CA=pub.banyanops.com/banyan-ca:v100.1.0
ROOTCONFIGJSONTEMPLATE=${KEYDIR}/root_config.json.tpl
ROOTCONFIGJSON=${KEYDIR}/root_config.json
ROOT_CSR_JSON_TEMPLATE=${KEYDIR}/root_csr.json.tpl
ROOT_CSR_JSON=${KEYDIR}/root_csr.json

# Sanity check for input
if [ "$#" -lt 6 ]; then
	echo "Usage: deploy-ca.sh <genkey> <localport> <enablescep> <restartpolicy> <ocsp_url> <org_name>"
	exit 1
fi

genkey=$1
localport=$2
enablescep=$3
restartpolicy=$4
ocsp_url=$5
org_name=$6

if [[ -z ${org_name} ]]; then
	cp ${ROOT_CSR_JSON_TEMPLATE} ${ROOT_CSR_JSON}
else
	sed "s|BNN Root CA|${org_name} BNN Root CA|g" ${ROOT_CSR_JSON_TEMPLATE} > ${ROOT_CSR_JSON}
fi

sudo docker pull ${BANYAN_CA}

if [ "$genkey" = "true" ]; then
	sudo docker run --rm -v ${KEYDIR}:${DKEYDIR} ${BANYAN_CA} genkey -initca ${DKEYDIR}/root_csr.json | \
		sudo docker run --rm -i -v ${KEYDIR}:${DKEYDIR} -w ${DKEYDIR} --entrypoint cfssljson ${BANYAN_CA} -bare ca
fi

if [[ ! -f ${KEYDIR}/ca.pem ]]; then
	echo "Error: Missing file ${KEYDIR}/ca.pem. You can run the following command to generate it: $0 true"
	exit 1
fi
if [[ ! -f ${KEYDIR}/ca-key.pem ]]; then
	echo "Error: Missing file ${KEYDIR}/ca-key.pem. You can run the following command to generate it: $0 true"
	exit 1
fi

sed "s|OCSP_URL|${ocsp_url}|g" ${ROOTCONFIGJSONTEMPLATE} >${ROOTCONFIGJSON}

sudo docker run -d -p 127.0.0.1:${localport}:8888 -v ${KEYDIR}:${DKEYDIR} --restart=${restartpolicy} --label com.banyanops.app="banyan-platform" --label com.banyanops.servicename="shieldsvc" --name banyan-ca ${BANYAN_CA} serve -address=0.0.0.0 -config=${DKEYDIR}/root_config.json -ca=${DKEYDIR}/ca.pem -ca-key=${DKEYDIR}/ca-key.pem -responder=${DKEYDIR}/ca.pem -responder-key=${DKEYDIR}/ca-key.pem

if [ "$enablescep" = "true" ]; then
	./deploy-scep.sh ${restartpolicy}
fi
